import type { Gitlab } from "../types"
import GitlabBaseService from "./base"

class Pipelines extends GitlabBaseService {
  /**
   * 获取特定GitLab流水线的详细信息。
   * @param {number} pipeline_id - 流水线的ID。
   * @param {string} created_at - 流水线的创建日期。
   * @returns 返回包含详细信息的Promise。
   */
  async getDetail(pipeline_id: number, created_at?: string) {
    const URL = `/projects/${this.project_id}/pipelines/${pipeline_id}`
    const res = await this.errorWarp<Gitlab.PipelineDetail>(
      () => this.get(URL),
      null
    )
    if (res === null) return null
    return { ...res, created_at }
  }

  /**
   * 获取特定项目的GitLab流水线列表。
   * @param {number} [page=1] - 结果的页码（默认值：1）。
   * @returns {Promise<Gitlab.Pipeline[]>} 一个解析为流水线数组的promise。
   */
  async getList(page = 1): Promise<Gitlab.Pipeline[]> {
    const URL = `/projects/${this.project_id}/pipelines`
    const params = { scope: "finished", per_page: 100, page }
    return this.errorWarp<Gitlab.Pipeline[]>(() => this.get(URL, params), [])
  }

  /**
   * 获取特定GitLab流水线的任务列表。
   * @param {number} pipeline_id - 流水线的ID。
   * @returns {Promise<Gitlab.Job[]>} 一个解析为任务数组的promise。
   */
  async getJobs(pipeline_id: number): Promise<Gitlab.Job[]> {
    const URL = `/projects/${this.project_id}/pipelines/${pipeline_id}/jobs`
    return this.errorWarp<Gitlab.Job[]>(() => this.get(URL), [])
  }
}

export default Pipelines
